'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var material = require('@mui/material');

const env = {
    api: {
        endpoint: {
            defaultValue: "https://api.wa.alpha.wa-labs.com",
            type: "string",
            description: "Application api endpoint",
        },
        port: {
            defaultValue: 443,
            type: "number",
            description: "Application api port",
        },
        production: {
            defaultValue: false,
            type: "boolean",
            description: "Production environment",
        },
        routePrefix: {
            defaultValue: "/v3",
            type: "string",
            description: "Api route prefix",
        },
        signinRoute: {
            defaultValue: "/account/users/signin",
            type: "string",
            description: "Api sign in route",
        },
        signoutRoute: {
            defaultValue: "/account/sessions/current",
            type: "string",
            description: "Api sign out route",
        },
    },
    app: {
        alphaWatermark: {
            defaultValue: true,
            type: "boolean",
            description: "Show alpha wartermark",
        },
        favicon: {
            defaultValue: "https://storage.googleapis.com/archer-app/favicons/home.png",
            type: "string",
            description: "App favicon path",
        },
        logo: {
            defaultValue: "https://storage.googleapis.com/archer-app/logos/ArcherLogo_red.png",
            type: "string",
            description: "App logo path",
        },
        passwordFreeSigninEnabled: {
            defaultValue: true,
            type: "boolean",
            description: "Show password free sign in on login page",
        },
        resetPasswordEnabled: {
            defaultValue: true,
            type: "boolean",
            description: "Show reset password on login page",
        },
        rootBackground: {
            defaultValue: "https://storage.googleapis.com/archer-app-test/media/images/interdoc/background.jpg",
            type: "string",
            description: "App background image",
        },
        signupEnabled: {
            defaultValue: true,
            type: "boolean",
            description: "Show sign up on login page",
        },
    },
    client: {
        contact: {
            defaultValue: "contact@whitearrow.com",
            type: "string",
            description: "Client email address",
        },
        name: {
            defaultValue: "White Arrow",
            type: "string",
            description: "Client name",
        },
        support: {
            defaultValue: "support@whitearrow.com",
            type: "string",
            description: "Support email address",
        },
        website: {
            defaultValue: "www.whitearrow.com",
            type: "string",
            description: "Client website",
        },
    },
    debug: {
        consoleLogger: {
            defaultValue: true,
            type: "boolean",
            description: "Enable console logger",
        },
    },
    front: {
        baseHostname: {
            defaultValue: "https://alpha.wa-labs.com",
            type: "string",
            description: "",
        },
        hostname: {
            defaultValue: "https://alpha.wa-labs.com",
            type: "string",
            description: "",
        },
        production: {
            defaultValue: true,
            type: "boolean",
            description: "Production environment",
        },
    },
    googleAnalytics: {
        key: {
            defaultValue: "UA-103938006-2",
            type: "string",
            description: "Google Analytics key",
        },
    },
    stripe: {
        token: {
            defaultValue: "pk_test_GW8Rc6z2mA6vxcjgUuGumuJt",
            type: "string",
            description: "Stripe key",
        },
    },
    theme: {
        primaryColor: {
            defaultValue: "#FF0000",
            type: "color",
            description: "Theme primary color",
        },
        secondaryColor: {
            defaultValue: "#808080",
            type: "color",
            description: "Theme secondary color",
        },
    },
};

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

const SecurityContext = react.createContext({ access: {} });
const SecurityContextProvider = SecurityContext.Provider;
/**
 * NerdSecurityAgentWrapper
 *
 * @param {NerdSecurityAgentWrapperProps} props component props
 * @returns {null} NerdSecurityAgentWrapper
 */
function NerdSecurityAgentWrapper(props) {
    const queryString = window.location.search;
    const highlightFromUrl = new URLSearchParams(queryString).get("hightlightSecurityGates");
    const { overwrite, children, access } = props;
    const highlight = highlightFromUrl === "true"
        ? true
        : highlightFromUrl === "false"
            ? false
            : props.highlight;
    return (jsxRuntime.jsx(SecurityContextProvider, Object.assign({ value: { overwrite, highlight, access } }, { children: children })));
}

/**
 * NerdSecurityGate
 *
 * @param {propsType & optionals} props component props
 * @returns {ReactElement} NerdSecurityGate
 */
function NerdSecurityGate(props) {
    const { id, children, userServices, childrenType = "component", redirect, } = props;
    const securityContext = react.useContext(SecurityContext);
    const access = securityContext.access;
    const [hasAccess, setHasAccess] = react.useState();
    const requiredRoles = access[id];
    const CLICK_TO_COPY = "Click to copy";
    const COPIED = "Copied !";
    const [tooltipText, setTooltipText] = react.useState(CLICK_TO_COPY);
    /**
     * Copy to clipboard
     *
     * @param {MouseEvent<HTMLSpanElement, MouseEvent>} e Click Event
     * @returns {Promise<void>}
     */
    function copy(e) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!navigator.clipboard)
                return;
            const value = e.currentTarget.textContent;
            if (value !== null) {
                yield navigator.clipboard.writeText(value);
                setTooltipText(COPIED);
            }
        });
    }
    react.useEffect(() => {
        var _a;
        const userAccess = securityContext.overwrite
            ? securityContext.overwrite
            : userServices;
        let _hasAccess = false;
        if (Array.isArray(requiredRoles) && requiredRoles.length > 0 && id !== "") {
            if (userAccess) {
                if (userAccess["account"].includes("superadmin"))
                    _hasAccess = true;
                let i = 0;
                while (i < requiredRoles.length && !_hasAccess) {
                    const serviceRole = requiredRoles[i];
                    const [service, role] = serviceRole.split(":");
                    if ((_a = userAccess[service]) === null || _a === void 0 ? void 0 : _a.includes(role)) {
                        _hasAccess = true;
                    }
                    i++;
                }
            }
        }
        else
            _hasAccess = true;
        setHasAccess(_hasAccess);
    }, []);
    react.useEffect(() => {
        if (hasAccess === false && childrenType === "route") {
            redirect === null || redirect === void 0 ? void 0 : redirect();
        }
    }, [hasAccess]);
    if (hasAccess) {
        if (securityContext.highlight && childrenType === "component") {
            return (jsxRuntime.jsxs(material.Box, Object.assign({ sx: {
                    border: "1px rgb(85,175,245) solid",
                    borderRadius: "4px",
                    margin: "3px",
                    backgroundColor: "rgba(85,175,245,0.1)",
                } }, { children: [jsxRuntime.jsx(material.Grid, Object.assign({ container: true }, { children: jsxRuntime.jsx(material.Tooltip, Object.assign({ title: tooltipText }, { children: jsxRuntime.jsx(material.Grid, Object.assign({ item: true, sx: {
                                    height: "18px",
                                    maxWidth: "50%",
                                    marginLeft: "auto",
                                    borderBottomLeftRadius: "8px",
                                    backgroundColor: "rgb(85,175,245)",
                                    padding: "0 5px 0 5px",
                                } }, { children: jsxRuntime.jsx(material.Typography, Object.assign({ onClick: copy, onMouseOver: () => setTooltipText(CLICK_TO_COPY), sx: {
                                        color: "white",
                                        fontSize: "12px",
                                        overflow: "hidden",
                                        whiteSpace: "nowrap",
                                        textOverflow: "ellipsis",
                                    } }, { children: id })) })) })) })), children] })));
        }
        else
            return jsxRuntime.jsx(jsxRuntime.Fragment, { children: children });
    }
    else
        return null;
}

exports.NerdSecurityAgentWrapper = NerdSecurityAgentWrapper;
exports.NerdSecurityGate = NerdSecurityGate;
exports.SecurityContext = SecurityContext;
exports.env = env;
//# sourceMappingURL=index.js.map
